@@ -40,7 +40,7 @@ import adtlog
 progname = "<VirtSubproc>"
 devnull_read = open('/dev/null', 'r')
 caller = __main__
-copy_timeout = int(os.getenv('ADT_VIRT_COPY_TIMEOUT', '300'))
+copy_timeout = int(os.getenv('AUTOPKGTEST_VIRT_COPY_TIMEOUT', '300'))
 
 downtmp_open = None  # downtmp after opening testbed
 downtmp = None  # current downtmp (None after close)
@@ -278,7 +278,7 @@ def downtmp_mktemp(path):
                    downp=True)
         return path
     else:
-        d = check_exec(['mktemp', '--directory', '--tmpdir', 'adt-run.XXXXXX'],
+        d = check_exec(['mktemp', '--directory', '--tmpdir', 'autopkgtest.XXXXXX'],
                        downp=True, outp=True)
         check_exec(['chmod', '1777', d], downp=True)
         return d
@@ -337,9 +337,8 @@ def cmd_reboot(c, ce):
     if len(c) > 1 and c[1] == 'prepare-only':
         adtlog.info('state saved, waiting for testbed to reboot...')
     else:
-        # FIXME: kill dhclient, workaround for LP #1556175
         execute_timeout(None, 30, auxverb +
-                        ['sh', '-c', 'pkill -9 dhclient >/dev/null 2>&1; (sleep 3; reboot) >/dev/null 2>&1 &'])
+                        ['sh', '-c', '(sleep 3; reboot) >/dev/null 2>&1 &'])
     caller.hook_wait_reboot()
 
     # restore downtmp
@@ -603,11 +602,14 @@ def cmd_shell(c, ce):
         except KeyError:
             pass
         cmd += 'bash -i'
-        with open('/dev/tty', 'rb') as sin:
-            with open('/dev/tty', 'wb') as sout:
-                with open('/dev/tty', 'wb') as serr:
-                    subprocess.call(auxverb + ['sh', '-c', cmd],
-                                    stdin=sin, stdout=sout, stderr=serr)
+        try:
+            with open('/dev/tty', 'rb') as sin:
+                with open('/dev/tty', 'wb') as sout:
+                    with open('/dev/tty', 'wb') as serr:
+                        subprocess.call(auxverb + ['sh', '-c', cmd],
+                                        stdin=sin, stdout=sout, stderr=serr)
+        except (OSError, IOError) as e:
+            adtlog.error('Cannot run shell: %s' % e)
 
 
 def command():
